@@ -30,6 +30,15 @@ def cli():
     required=False,
     show_default=True,
 )
-def run(port=5000, debug=False, socket=False):
+@click.option(
+    "--max_workers",
+    help="Max workers",
+    type=int,
+    default=False,
+    required=False,
+    show_default=True,
+)
+def run(port=5000, debug=False, socket=False, max_workers=2):
     print("Starting processors server")
-    manager.start_server(port)
+    max_workers = max_workers or 2
+    manager.start_server(port, max_workers)
